@@ -149,9 +149,13 @@ def r_julei(data):
     print("dev.new()\nX<-read.table('clipboda',header=T)\n=cor(X) \nhc<-hclust(d)\nplot(hc)")
 
 def cengci_julei(data1,group_size):
-    print("要先使用排列方法使得，数据以一定的顺序进行查找，方便查找和使用。")
+    z_scaler = preprocessing.StandardScaler()
+    print("如果列的坐标混乱，要先使用排列方法使得，数据以一定的顺序进行查找，方便查找和使用。")
     data1.sort_index()
+    print("同时也要进行数据的")
     data1 = np.array(data1)
+    data1 = z_scaler.fit_transform(data1)
+
     print("聚类分析的步骤")
     print(". 读入数据、观察数据。\
 2. 确定数据是否需要标准化，进行标准化\
